#! /bin/bash
# Install script for privoxy by Martijn Dekker <martijn@inlv.org>
# Generated by privoxy.SlackBuild for privoxy-3.0.3p2-i486-1McD.tgz on 14-Apr-2006

upd_conf() {
 	# If there's no config file by that name, mv it over:
 	if ! test -f $1; then
 		mv $1.new $1
 	elif diff -q $1 $1.new; then	# toss the redundant copy
 		rm $1.new
 	elif ! test -s $1.new; then
 		rm $1.new   # do not keep empty initial files (e.g. log)
 	fi
 	# Otherwise, we leave the .new copy for the admin to consider...
}

# Update configuration files
{
	upd_conf etc/privoxy/config
	upd_conf etc/privoxy/default.action
	upd_conf etc/privoxy/default.filter
	upd_conf etc/privoxy/standard.action
	upd_conf etc/privoxy/templates/blocked
	upd_conf etc/privoxy/templates/cgi-error-404
	upd_conf etc/privoxy/templates/cgi-error-bad-param
	upd_conf etc/privoxy/templates/cgi-error-disabled
	upd_conf etc/privoxy/templates/cgi-error-file
	upd_conf etc/privoxy/templates/cgi-error-file-read-only
	upd_conf etc/privoxy/templates/cgi-error-modified
	upd_conf etc/privoxy/templates/cgi-error-parse
	upd_conf etc/privoxy/templates/cgi-style.css
	upd_conf etc/privoxy/templates/connect-failed
	upd_conf etc/privoxy/templates/default
	upd_conf etc/privoxy/templates/edit-actions-add-url-form
	upd_conf etc/privoxy/templates/edit-actions-for-url
	upd_conf etc/privoxy/templates/edit-actions-for-url-filter
	upd_conf etc/privoxy/templates/edit-actions-list
	upd_conf etc/privoxy/templates/edit-actions-list-button
	upd_conf etc/privoxy/templates/edit-actions-list-section
	upd_conf etc/privoxy/templates/edit-actions-list-url
	upd_conf etc/privoxy/templates/edit-actions-remove-url-form
	upd_conf etc/privoxy/templates/edit-actions-url-form
	upd_conf etc/privoxy/templates/mod-local-help
	upd_conf etc/privoxy/templates/mod-support-and-service
	upd_conf etc/privoxy/templates/mod-title
	upd_conf etc/privoxy/templates/mod-unstable-warning
	upd_conf etc/privoxy/templates/no-such-domain
	upd_conf etc/privoxy/templates/show-request
	upd_conf etc/privoxy/templates/show-status
	upd_conf etc/privoxy/templates/show-status-file
	upd_conf etc/privoxy/templates/show-url-info
	upd_conf etc/privoxy/templates/show-version
	upd_conf etc/privoxy/templates/toggle
	upd_conf etc/privoxy/templates/toggle-mini
	upd_conf etc/privoxy/templates/untrusted
	upd_conf etc/privoxy/trust
	upd_conf etc/privoxy/user.action
	upd_conf etc/rc.d/rc.privoxy
} | sed 's/^/[1mConfig alert: [0m/'

# Initialize log files if not already present
upd_conf var/log/privoxy/jarfile 2>&1 > /dev/null
upd_conf var/log/privoxy/logfile 2>&1 > /dev/null

# Set up user and permissions
echo "Setting up user 'privoxy' and group 'privoxy'."
grep -q ^privoxy: etc/group || groupadd privoxy
grep -q ^privoxy: etc/passwd && ACTION=mod || ACTION=add
user$ACTION -g privoxy -d /var/run/privoxy -c "Privacy Proxy"	\
 	-s /bin/false privoxy
chown -R privoxy:privoxy var/log/privoxy var/run/privoxy	\
 	etc/privoxy/*.new

# Make us start on boot
if ! grep -q "rc.privoxy start" etc/rc.d/rc.local; then
 	echo "Adding Privoxy to /etc/rc.d/rc.local so it starts at bootup time."
 	cat >> etc/rc.d/rc.local <<EOF

# Privoxy, the privacy web proxy
test -x /etc/rc.d/rc.privoxy && . /etc/rc.d/rc.privoxy start
EOF
else
 	echo "Privoxy is already in /etc/rc.d/rc.local ."
fi
